@@ -11,72 +11,77 @@
     unused_must_use
 )]
 
+
 use std::collections::HashMap;
 use std::fmt::Display;
 use std::fmt::Formatter;
 use std::fmt::Result;
 
-use python::List;
-use python::Object;
-use python::Int;
-use python::Float;
-use python::Bool;
-use python::_String;
+// use python::Object;
+// use python::Int;
+// use python::Float;
+// use python::Bool;
+// use python::_String;
+// use python::List;
 
-// builtins
-use python::print;
-use python::len;
-use python::repr;
+// // builtins.rs
+// use python::print;
+// use python::len;
+// use python::repr;
 
-
-// impl _Object for List {
-//     fn __str__(self) {
-//         println!("{:?}", self.inner);
-//     }
-// }
-
-// pub fn len<T>(_object: &T) -> i32 where T: _Object {
-//     _object.__len__()
-// }
-
-// pub fn str<T>(_object: &T) where T: _Object {
-//     _object.__str__()
-// }
-
-// impl _Object for List<Int> {
-//     fn __str__(self) {
-//         println!("{:?}", self.inner);
-//     }
-// }
-
-
-// .. and so on
+use python::*;
 
 
 fn main() {
     // example of what i want
 
     let mut python_list =
-        List::from_string(String::from("123123"));
-    python_list.append_int(123);
-    python_list.append_float(123.123);
-    python_list.append_float(123.123);
-    python_list.append_float(123.123);
-    python_list.append_string(String::from("asdasd"));
-    python_list.append_list(
-        List::from_string("andrew".to_string()));
-    python_list.append_pstring(
+        List::from(String::from("123123"));
+
+    python_list.append_back(123);
+    python_list.append_front("salutare");
+
+    python_list.append_back(123);
+
+    python_list.append_back(List::from(List::from(String::from("working"))));
+
+    python_list.append_back(123.123);
+    python_list.append_back(123.123);
+    python_list.append_back(123.123);
+    python_list.append_back(String::from("asdasd"));
+
+    python_list.append_back(
+        List::from("andrew".to_string()));
+    python_list.append_back(
         _String::from_string(
             String::from("python string")));
 
-    python_list.append_pbool(Bool::new(true));
-    python_list.append_pbool(Bool::new(false));
-    python_list.append_bool(false);
+    python_list.append_back(Bool::new(true));
+    python_list.append_back(Bool::new(false));
+    python_list.append_back(false);
 
     print(&python_list);
     print(len(&python_list));
 
 
+    // python_list.append_front("salutare");
+
+    for o in python_list.iter() {
+        print(o)
+    }
+
+
+    let list_from_str = "123123".parse::<List>().unwrap();
+    print(&list_from_str);
+
+    let iter = (0..5).into_iter();
+    // let list_from_iterator: List = iter.collect();
+    let list_from_iterator = iter.collect::<List>();
+    print(&list_from_iterator);
+
+
+
+
     // let oo = Object::Int(Int::new(123));
     // println!("{}", oo);
 
